Technology

Enum Technology 

#[repr(u8)]
pub enum Technology { TechnologyUnknown = 0, TechnologyLithiumIon = 1, TechnologyLeadAcid = 2, TechnologyLithiumPolymer = 3, TechnologyNickelMetalHydride = 4, TechnologyNickelCadmium = 5, TechnologyNickelZinc = 6, TechnologyLithiumIronPhosphate = 7, TechnologyRechargeableAlkalineManganese = 8, }
Possible battery technologies.

New members might be added to this enum in the next versions, so users are required to properly handle that case.

Enum members are prefixed here in order to not have “redeclaration of enumerator” error in C.

Variants



TechnologyUnknown = 0



TechnologyLithiumIon = 1



TechnologyLeadAcid = 2



TechnologyLithiumPolymer = 3



TechnologyNickelMetalHydride = 4



TechnologyNickelCadmium = 5



TechnologyNickelZinc = 6



TechnologyLithiumIronPhosphate = 7



TechnologyRechargeableAlkalineManganese = 8